# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListStrategyRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'domain_id': 'str',
        'offset': 'int',
        'limit': 'int',
        'include_tenant_rule_set': 'bool',
        'name': 'str',
        'is_valid': 'bool',
        'type': 'str',
        'cloud_project_id': 'str'
    }

    attribute_map = {
        'domain_id': 'domain_id',
        'offset': 'offset',
        'limit': 'limit',
        'include_tenant_rule_set': 'include_tenant_rule_set',
        'name': 'name',
        'is_valid': 'is_valid',
        'type': 'type',
        'cloud_project_id': 'cloud_project_id'
    }

    def __init__(self, domain_id=None, offset=None, limit=None, include_tenant_rule_set=None, name=None, is_valid=None, type=None, cloud_project_id=None):
        """ListStrategyRequest

        The model defined in huaweicloud sdk

        :param domain_id: 租户ID
        :type domain_id: str
        :param offset: 偏移量，表示从此偏移量开始查询，offset大于等于0
        :type offset: int
        :param limit: 每页显示的条目数量
        :type limit: int
        :param include_tenant_rule_set: 是否包含租户级规则
        :type include_tenant_rule_set: bool
        :param name: 策略名称，用于模糊查询
        :type name: str
        :param is_valid: 是否有效
        :type is_valid: bool
        :param type: 策略类型
        :type type: str
        :param cloud_project_id: 项目ID
        :type cloud_project_id: str
        """
        
        

        self._domain_id = None
        self._offset = None
        self._limit = None
        self._include_tenant_rule_set = None
        self._name = None
        self._is_valid = None
        self._type = None
        self._cloud_project_id = None
        self.discriminator = None

        self.domain_id = domain_id
        self.offset = offset
        self.limit = limit
        self.include_tenant_rule_set = include_tenant_rule_set
        if name is not None:
            self.name = name
        if is_valid is not None:
            self.is_valid = is_valid
        if type is not None:
            self.type = type
        if cloud_project_id is not None:
            self.cloud_project_id = cloud_project_id

    @property
    def domain_id(self):
        """Gets the domain_id of this ListStrategyRequest.

        租户ID

        :return: The domain_id of this ListStrategyRequest.
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this ListStrategyRequest.

        租户ID

        :param domain_id: The domain_id of this ListStrategyRequest.
        :type domain_id: str
        """
        self._domain_id = domain_id

    @property
    def offset(self):
        """Gets the offset of this ListStrategyRequest.

        偏移量，表示从此偏移量开始查询，offset大于等于0

        :return: The offset of this ListStrategyRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListStrategyRequest.

        偏移量，表示从此偏移量开始查询，offset大于等于0

        :param offset: The offset of this ListStrategyRequest.
        :type offset: int
        """
        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this ListStrategyRequest.

        每页显示的条目数量

        :return: The limit of this ListStrategyRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListStrategyRequest.

        每页显示的条目数量

        :param limit: The limit of this ListStrategyRequest.
        :type limit: int
        """
        self._limit = limit

    @property
    def include_tenant_rule_set(self):
        """Gets the include_tenant_rule_set of this ListStrategyRequest.

        是否包含租户级规则

        :return: The include_tenant_rule_set of this ListStrategyRequest.
        :rtype: bool
        """
        return self._include_tenant_rule_set

    @include_tenant_rule_set.setter
    def include_tenant_rule_set(self, include_tenant_rule_set):
        """Sets the include_tenant_rule_set of this ListStrategyRequest.

        是否包含租户级规则

        :param include_tenant_rule_set: The include_tenant_rule_set of this ListStrategyRequest.
        :type include_tenant_rule_set: bool
        """
        self._include_tenant_rule_set = include_tenant_rule_set

    @property
    def name(self):
        """Gets the name of this ListStrategyRequest.

        策略名称，用于模糊查询

        :return: The name of this ListStrategyRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ListStrategyRequest.

        策略名称，用于模糊查询

        :param name: The name of this ListStrategyRequest.
        :type name: str
        """
        self._name = name

    @property
    def is_valid(self):
        """Gets the is_valid of this ListStrategyRequest.

        是否有效

        :return: The is_valid of this ListStrategyRequest.
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """Sets the is_valid of this ListStrategyRequest.

        是否有效

        :param is_valid: The is_valid of this ListStrategyRequest.
        :type is_valid: bool
        """
        self._is_valid = is_valid

    @property
    def type(self):
        """Gets the type of this ListStrategyRequest.

        策略类型

        :return: The type of this ListStrategyRequest.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ListStrategyRequest.

        策略类型

        :param type: The type of this ListStrategyRequest.
        :type type: str
        """
        self._type = type

    @property
    def cloud_project_id(self):
        """Gets the cloud_project_id of this ListStrategyRequest.

        项目ID

        :return: The cloud_project_id of this ListStrategyRequest.
        :rtype: str
        """
        return self._cloud_project_id

    @cloud_project_id.setter
    def cloud_project_id(self, cloud_project_id):
        """Sets the cloud_project_id of this ListStrategyRequest.

        项目ID

        :param cloud_project_id: The cloud_project_id of this ListStrategyRequest.
        :type cloud_project_id: str
        """
        self._cloud_project_id = cloud_project_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListStrategyRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
